# encoding: utf-8
#
# Copyright (C) 2020 willipink.eu
# Author Moritz Münch moritzmuench@mailbox.org
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.



from hashlib import sha256
from random import random

from django.core.cache import cache
from django.http import Http404

from .models import Coin


def get_last_modified_coin(request):
    return cache.get('last_modified_coin', set_last_modified_coin())


def set_last_modified_coin():
    ''' set and return the datetime of the last coin added '''
    try:
        last_modified = Coin.objects.latest('date_modified').date_modified
    except Coin.DoesNotExist:
        raise Http404(f'Das Land "{name_iso}" existiert nicht')
    cache.set('last_modified_coin', last_modified)
    return last_modified


def get_last_modified_country(request, name_iso):
    return cache.get(f'last_modified_{name_iso}', set_last_modified_country(name_iso))


def set_last_modified_country(name_iso):
    ''' return the datetime of the last coin added to a country '''
    try:
        last_modified = Coin.objects.filter(country=name_iso).latest('date_modified').date_modified
    except Coin.DoesNotExist:
        raise Http404(f'Das Land "{name_iso}" existiert nicht')
    cache.set(f'last_modified_{name_iso}', last_modified)
    return last_modified
